@@ -16,7 +16,9 @@ Usage::
     session_client: CostExplorerClient = session.client("ce")
     ```
 """
-from mypy_boto3_ce.client import CostExplorerClient as Client, CostExplorerClient
+from mypy_boto3_ce.client import CostExplorerClient
+
+Client = CostExplorerClient
 
 
 __all__ = ("Client", "CostExplorerClient")
